summaryrefslogtreecommitdiffstats
path: root/xorg
diff options
context:
space:
mode:
authorJay Sorg <jay.sorg@gmail.com>2011-11-18 19:55:50 -0800
committerJay Sorg <jay.sorg@gmail.com>2011-11-18 19:55:50 -0800
commit9eb054de9d2dc9e234f1ee7e22d4e7546361f679 (patch)
treecfefe077ec62e7965a9052fac7d260c87320e2b4 /xorg
parent2c7c29053d9e9298cc9558a8937a8c6b3f1d5b39 (diff)
downloadxrdp-proprietary-9eb054de9d2dc9e234f1ee7e22d4e7546361f679.tar.gz
xrdp-proprietary-9eb054de9d2dc9e234f1ee7e22d4e7546361f679.zip
xorg build
Diffstat (limited to 'xorg')
-rwxr-xr-xxorg/X11R7.6/buildx.sh44
-rw-r--r--xorg/X11R7.6/libXext-1.2.0.patch13
-rw-r--r--xorg/X11R7.6/x11_file_list.txt7
3 files changed, 59 insertions, 5 deletions
diff --git a/xorg/X11R7.6/libXext-1.2.0.patch b/xorg/X11R7.6/libXext-1.2.0.patch
new file mode 100644
index 00000000..2ddc7ec0
--- /dev/null
+++ b/xorg/X11R7.6/libXext-1.2.0.patch
@@ -0,0 +1,13 @@
+diff --git a/src/Xge.c b/src/Xge.c
+index 7a583e5..2ea5d27 100644
+--- a/src/Xge.c
++++ b/src/Xge.c
+@@ -294,7 +294,7 @@ _xgeEventToWire(Display* dpy, XEvent* re, xEvent* event)
+ /*
+ * Extensions need to register callbacks for their events.
+ */
+-Bool
++_X_HIDDEN Bool
+ xgeExtRegister(Display* dpy, int offset, XExtensionHooks* callbacks)
+ {
+ XGEExtNode* newExt;
diff --git a/xorg/X11R7.6/x11_file_list.txt b/xorg/X11R7.6/x11_file_list.txt
index bd03cfff..6d6d8113 100644
--- a/xorg/X11R7.6/x11_file_list.txt
+++ b/xorg/X11R7.6/x11_file_list.txt
@@ -46,7 +46,10 @@ damageproto-1.2.1.tar.bz2 : damageproto-1.2.1
libXdamage-1.1.3.tar.bz2 : libXdamage-1.1.3 :
makedepend-1.0.3.tar.bz2 : makedepend-1.0.3 :
libxml2-sources-2.7.8.tar.gz : libxml2-2.7.8 :
-MesaLib-7.10.3.tar.bz2 : Mesa-7.10.3 :
+libpng-1.2.46.tar.gz : libpng-1.2.46 :
+cairo-1.8.8.tar.gz : cairo-1.8.8 :
+expat-2.0.1.tar.gz : expat-2.0.1 :
+MesaLib-7.10.3.tar.bz2 : Mesa-7.10.3 : --with-expat=$PREFIX_DIR
randrproto-1.3.2.tar.bz2 : randrproto-1.3.2 :
renderproto-0.11.1.tar.bz2 : renderproto-0.11.1 :
fixesproto-4.1.2.tar.bz2 : fixesproto-4.1.2 :
@@ -83,7 +86,6 @@ libXmu-1.1.0.tar.bz2 : libXmu-1.1.0
libXxf86vm-1.1.1.tar.bz2 : libXxf86vm-1.1.1 :
libXpm-3.5.9.tar.bz2 : libXpm-3.5.9 :
libXaw-1.0.8.tar.bz2 : libXaw-1.0.8 :
-expat-2.0.1.tar.gz : expat-2.0.1 :
pixman-0.15.20.tar.bz2 : pixman-0.15.20 :
freetype-2.4.6.tar.bz2 : freetype-2.4.6 :
mkfontdir-1.0.6.tar.bz2 : mkfontdir-1.0.6 :
@@ -92,4 +94,5 @@ xdriinfo-1.0.4.tar.bz2 : xdriinfo-1.0.4
xorg-server-1.9.3.tar.bz2 : xorg-server-1.9.3 :
applewmproto-1.4.1.tar.bz2 : applewmproto-1.4.1 :
bdftopcf-1.0.3.tar.bz2 : bdftopcf-1.0.3 :
+intltool-0.41.1.tar.gz : intltool-0.41.1 :
xkeyboard-config-2.0.tar.bz2 : xkeyboard-config-2.0 :
diff --git a/xorg/X11R7.6/buildx.sh b/xorg/X11R7.6/buildx.sh
index bcfa2295..8abbc90c 100755
--- a/xorg/X11R7.6/buildx.sh
+++ b/xorg/X11R7.6/buildx.sh
@@ -20,6 +20,7 @@
# limitations under the License.
# flex bison libxml2-dev intltool
+# xsltproc
download_file()
{
@@ -68,11 +69,36 @@ download_file()
status=$?
cd ..
return $status
+ elif [ "$file" = "Python-2.5.tar.bz2" ]; then
+ wget -cq http://www.python.org/ftp/python/2.5/Python-2.5.tar.bz2
+ status=$?
+ cd ..
+ return $status
elif [ "$file" = "Python-2.7.tar.bz2" ]; then
wget -cq http://www.python.org/ftp/python/2.7/Python-2.7.tar.bz2
status=$?
cd ..
return $status
+ elif [ "$file" = "expat-2.0.1.tar.gz" ]; then
+ wget -cq http://server1.xrdp.org/xrdp/expat-2.0.1.tar.gz
+ status=$?
+ cd ..
+ return $status
+ elif [ "$file" = "cairo-1.8.8.tar.gz" ]; then
+ wget -cq http://server1.xrdp.org/xrdp/cairo-1.8.8.tar.gz
+ status=$?
+ cd ..
+ return $status
+ elif [ "$file" = "libpng-1.2.46.tar.gz" ]; then
+ wget -cq http://server1.xrdp.org/xrdp/libpng-1.2.46.tar.gz
+ status=$?
+ cd ..
+ return $status
+ elif [ "$file" = "intltool-0.41.1.tar.gz" ]; then
+ wget -cq http://launchpad.net/intltool/trunk/0.41.1/+download/intltool-0.41.1.tar.gz
+ status=$?
+ cd ..
+ return $status
else
wget -cq $download_url/$file
status=$?
@@ -150,8 +176,13 @@ make_it()
fi
fi
# configure module - we only need to do this once
cd $mod_name
+ # check for patches
+ if [ -e ../../$mod_name.patch ]; then
+ patch -p1 ../../$mod_name.patch
+ fi
+ # now configure
./configure --prefix=$PREFIX_DIR $mod_args
if [ $? -ne 0 ]; then
echo "configuration failed for module $mn"
@@ -176,6 +207,14 @@ make_it()
exit 1
fi
+ # special case after installing python make this sym link
+ # so Mesa builds using this python version
+ case "$mod_name" in
+ *Python-2*)
+ ln -s python $PREFIX_DIR/bin/python2
+ ;;
+ esac
+
cd ../..
touch cookies/$mod_name
return 0
@@ -212,7 +251,7 @@ fi
export PREFIX_DIR=$1
export PKG_CONFIG_PATH=$PREFIX_DIR/lib/pkgconfig:$PREFIX_DIR/share/pkgconfig
export PATH=$PREFIX_DIR/bin:$PATH
-export CFLAGS=-fPIC
+#export CFLAGS=-fPIC
# prefix dir must exist...
if [ ! -d $PREFIX_DIR ]; then
@@ -266,4 +305,3 @@ do
make_it $mod_file $mod_dir "$mod_args"
done < $data_file
-
@@ -150,8 +176,13 @@ make_it()
fi
fi
- # configure module - we only need to do this once
+ # patch and configure module - we only need to do this once
cd $mod_name